@@ -9,9 +9,9 @@ pub trait FromResponse: Sized {
 #[async_trait::async_trait]
 impl<T: serde::de::DeserializeOwned> FromResponse for T {
     async fn from_response(response: reqwest::Response) -> crate::Result<Self> {
-        let text = response.text().await.context(crate::error::Http)?;
+        let text = response.text().await.context(crate::error::HttpSnafu)?;
 
         let de = &mut serde_json::Deserializer::from_str(&text);
-        serde_path_to_error::deserialize(de).context(crate::error::Json)
+        serde_path_to_error::deserialize(de).context(crate::error::JsonSnafu)
     }
 }
