@@ -61,6 +61,8 @@ pub struct Content {
     pub name: String,
     pub path: String,
     pub sha: String,
+    /// File content, Base64 encoded
+    pub content: Option<String>,
     pub size: i64,
     pub url: String,
     pub html_url: String,
@@ -84,20 +86,47 @@ impl ContentItems {
     }
 }
 
+impl Content {
+    /// Get content of a file from a repository.
+    /// ```no_run
+    /// # async fn run() -> octocrab::Result<()> {
+    ///
+    /// let mut content = octocrab::instance()
+    ///     .repos("owner", "repo")
+    ///     .get_content()
+    ///     .path("path/to/file")
+    ///     .r#ref("main")
+    ///     .send()
+    ///     .await?;
+    /// let contents = content.take_items();
+    /// let c = &contents[0];
+    /// let decoded_content = c.decoded_content().unwrap();
+    /// # Ok(())
+    /// # }
+    /// ```
+    pub fn decoded_content(&self) -> Option<String> {
+        self.content.as_ref().and_then(|c| {
+            let mut content = c.as_bytes().to_owned();
+            content.retain(|b| !b" \n\t\r\x0b\x0c".contains(b));
+            let c = base64::decode(&content).unwrap();
+            Some(String::from_utf8_lossy(&c).into_owned())
+        })
+    }
+}
+
 #[async_trait::async_trait]
 impl crate::FromResponse for ContentItems {
     async fn from_response(response: reqwest::Response) -> crate::Result<Self> {
-        let json: serde_json::Value = response.json().await.context(crate::error::Http)?;
+        let json: serde_json::Value = response.json().await.context(crate::error::HttpSnafu)?;
 
         if json.is_array() {
-
             Ok(ContentItems {
-                items: serde_json::from_value(json).context(crate::error::Serde)?,
+                items: serde_json::from_value(json).context(crate::error::SerdeSnafu)?,
             })
         } else {
             let mut items = Vec::new();
 
-            items.push(serde_json::from_value(json).context(crate::error::Serde)?);
+            items.push(serde_json::from_value(json).context(crate::error::SerdeSnafu)?);
 
             Ok(ContentItems { items })
         }
@@ -138,7 +167,7 @@ pub struct Release {
     pub url: Url,
     pub html_url: Url,
     pub assets_url: Url,
-    pub upload_url: Url,
+    pub upload_url: String,
     pub tarball_url: Option<Url>,
     pub zipball_url: Option<Url>,
     pub id: ReleaseId,
